@@ -9,7 +9,9 @@ From https://rosettacode.org/wiki/Sparkline_in_unicode#Python
 
 
 def generate(
-    arr: List[float], minimum: Optional[float] = None, maximum: Optional[float] = None,
+    arr: List[float],
+    minimum: Optional[float] = None,
+    maximum: Optional[float] = None,
 ) -> Tuple[float, float, str]:
     all_zeros = all(i == 0 for i in arr)
     if all_zeros:
@@ -29,7 +31,14 @@ def _create(
     max_ = fixed_max if fixed_max is not None else float(max(numbers))
     extent = _get_extent(max_, min_)
     spark = "".join(
-        __bars[min([__bar_count - 1, int((n - min_) / extent * __bar_count)])]
+        __bars[
+            min(
+                [
+                    __bar_count - 1,
+                    int((n - min_) / extent * __bar_count),
+                ]
+            )
+        ]
         for n in numbers
     )
     return min_, max_, spark
